==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicInternalFrameTitlePane__24MoveAction.h <==
// public class javax.swing.plaf.basic.BasicInternalFrameTitlePane$MoveAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 2818ad8e6cc2b68f javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction

// header file dependencies
// @dep_header javax_swing_AbstractAction

#include "javax/swing/AbstractAction.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$object	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$method$_init$a4e5e3befc8ae789(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vmethods	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$sub_refs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicInternalFrameTitlePane__24MoveAction.h <==
// public class javax.swing.plaf.basic.BasicInternalFrameTitlePane$MoveAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 2818ad8e6cc2b68f javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction

// header file dependencies
// @dep_header javax_swing_AbstractAction

#include "javax/swing/AbstractAction.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$object	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$method$_init$a4e5e3befc8ae789(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vmethods	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$sub_refs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24MoveAction_H_ */
